__all__ = [
    "DEFAULT_NH_COLLECTION_PORT",
    "DEFAULT_NH_PUBLISH_PORT",
]

# Default ports that are assigned to PUSH-PULL and PUB-SUB protocols of the notification hub.
DEFAULT_NH_COLLECTION_PORT = 4245
DEFAULT_NH_PUBLISH_PORT = 4246
